@@ -67,6 +67,7 @@ SubscriptionStateType = Literal["ACTIVE", "INACTIVE"]
 UnitType = Literal["BITS", "BYTES", "PACKETS", "REQUESTS"]
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -99,6 +100,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
